@@ -171,7 +171,11 @@ has 'label' => (
     builder => 'build_label',
 );
 has 'do_label' => ( isa => 'Bool', is => 'rw', default => 1 );
-sub build_label {
+has 'build_label_method' => ( is => 'rw', isa => 'CodeRef',
+    traits => ['Code'], handles => { 'build_label' => 'execute_method' },
+    default => sub { \&default_build_label },
+);
+sub default_build_label {
     my $self = shift;
     my $label = $self->name;
     $label =~ s/_/ /g;
@@ -939,7 +943,7 @@ HTML::FormHandler::Field - base class for fields
 
 =head1 VERSION
 
-version 0.40005
+version 0.40006
 
 =head1 SYNOPSIS
 
@@ -1127,8 +1131,11 @@ element as-is.
 The following are used in rendering HTML, but are handled specially.
 
    label       - Text label for this field. Defaults to ucfirst field name.
+   build_label_method - coderef for constructing the label
+   wrap_label_method - coderef for constructing a wrapped label
    id          - Useful for javascript (default is html_name. to prefix with
                  form name, use 'html_prefix' in your form)
+   build_id_method - coderef for constructing the id
    render_filter - Coderef for filtering fields before rendering. By default
                  changes >, <, &, " to the html entities
    disabled    - Boolean to set field disabled
@@ -1254,6 +1261,8 @@ For more about widgets, see L<HTML::FormHandler::Manual::Rendering>.
 
 See also the section in L<HTML::FormHandler::Manual::Intro#Defaults>.
 
+=over
+
 =item default_method, set_default
 
 Supply a coderef (which will be a method on the field) with 'default_method'
